==> ejc-car-impl-3.0.0-20231025.062605-34-sources.jar: com/ejianc/business/car/bean/MaintainMaterialEntity.java <==
package com.ejianc.business.car.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 车辆维修-材料费
 * 
 * @author generator
 * 
 */
 @TableName("ejc_car_maintain_material")
public class MaintainMaterialEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="maintain_id")
    private Long maintainId; // 维修id
    @TableField(value="material_name")
    private String materialName; // 材料名称
    @TableField(value="num")
    private BigDecimal num; // 数量
    @TableField(value="price")
    private BigDecimal price; // 单价
    @TableField(value="tax_mny")
    private BigDecimal taxMny; // 金额
    @TableField(value="memo")
    private String memo; // 备注
    @TableField(value="add_type")
    private String addType; // 新增类型 1自动 2手动

    public String getAddType() {
        return addType;
    }

    public void setAddType(String addType) {
        this.addType = addType;
    }




    public Long getMaintainId() {
        return maintainId;
    }

    public void setMaintainId(Long maintainId) {
        this.maintainId = maintainId;
    }
    public String getMaterialName() {
        return materialName;
    }

    public void setMaterialName(String materialName) {
        this.materialName = materialName;
    }
    public BigDecimal getNum() {
        return num;
    }

    public void setNum(BigDecimal num) {
        this.num = num;
    }
    public BigDecimal getPrice() {
        return price;
    }

    public void setPrice(BigDecimal price) {
        this.price = price;
    }
    public BigDecimal getTaxMny() {
        return taxMny;
    }

    public void setTaxMny(BigDecimal taxMny) {
        this.taxMny = taxMny;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    
}

==> ejc-car-impl-3.0.0-20251031.075738-69-sources.jar: com/ejianc/business/car/bean/MaintainMaterialEntity.java <==
package com.ejianc.business.car.bean;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;

import java.math.BigDecimal;

/**
 * 车辆维修-材料费
 * 
 * @author generator
 * 
 */
 @TableName("ejc_car_maintain_material")
public class MaintainMaterialEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="maintain_id")
    private Long maintainId; // 维修id
    @TableField(value="material_name")
    private String materialName; // 材料名称
    @TableField(value="num")
    private BigDecimal num; // 数量
    @TableField(value="price")
    private BigDecimal price; // 单价
    @TableField(value="tax_mny")
    private BigDecimal taxMny; // 金额
    @TableField(value="memo")
    private String memo; // 备注
    @TableField(value="add_type")
    private String addType; // 新增类型 1自动 2手动

    public String getAddType() {
        return addType;
    }

    public void setAddType(String addType) {
        this.addType = addType;
    }




    public Long getMaintainId() {
        return maintainId;
    }

    public void setMaintainId(Long maintainId) {
        this.maintainId = maintainId;
    }
    public String getMaterialName() {
        return materialName;
    }

    public void setMaterialName(String materialName) {
        this.materialName = materialName;
    }
    public BigDecimal getNum() {
        return num;
    }

    public void setNum(BigDecimal num) {
        this.num = num;
    }
    public BigDecimal getPrice() {
        return price;
    }

    public void setPrice(BigDecimal price) {
        this.price = price;
    }
    public BigDecimal getTaxMny() {
        return taxMny;
    }

    public void setTaxMny(BigDecimal taxMny) {
        this.taxMny = taxMny;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    
}
